Module prelude

Module prelude 

Prelude that wires up the built-in Ruby-like standard library for yamrb. Each submodule exposes initializers that install core classes and constants into a VM so user bytecode starts with the expected environment.

Modules

array
class
enumerable
exception
falseclass
float
hash
integer
module
nilclass
object
proc
range
shared_memory
string
symbol
trueclass

Functions

prelude