SharedMemory

Struct SharedMemory 

pub struct SharedMemory {
    pub memory: Pin<Box<[u8]>>,
    pub size: usize,
}

Fields

memory: Pin<Box<[u8]>>size: usize

Implementations

Source

impl SharedMemory

pub fn new(size: usize) -> Self

pub fn offset_in_memory(&self) -> usize

pub fn as_mut_ptr(&mut self) -> *mut u8

pub fn write(&mut self, offset: usize, data: &[u8])

pub fn read(&self, offset: usize, size: usize) -> Vec<u8>

pub fn read_u8(&self, offset: usize) -> u8

pub fn leak(&mut self) -> *mut u8

HINT: SharedMemory’s memory region cannot be cleared when the reference count drops to zero. Even if it leaks, Cloudflare Workers deallocate memory on a per-Wasm instance basis every time the request is done; so it does not cause memory leaks.