RClass

Struct RClass 

pub struct RClass {
    pub module: Rc<RModule>,
    pub super_class: Option<Rc<RClass>>,
    pub singleton_class_ref: RefCell<Option<Rc<RClass>>>,
    pub is_singleton: bool,
    pub extended_modules: RefCell<Vec<Rc<RModule>>>,
}
Ruby class metadata, including its module namespace and optional superclass. Attributes and methods required for Class implementation are stored in the associated RModule.

Fields

module: Rc<RModule>super_class: Option<Rc<RClass>>singleton_class_ref: RefCell<Option<Rc<RClass>>>is_singleton: boolextended_modules: RefCell<Vec<Rc<RModule>>>

Implementations

Source

impl RClass

pub fn new( name: &str, super_class: Option<Rc<RClass>>, parent_module: Option<Rc<RModule>>, ) -> Self

pub fn new_singleton( name: &str, super_class: Option<Rc<RClass>>, parent_module: Option<Rc<RModule>>, ) -> Self

pub fn getmcnst(&self, name: &str) -> Option<Rc<RObject>>

pub fn find_method(&self, name: &str) -> Option<RProc>

pub fn full_name(&self) -> String

Source

impl RClass

pub fn from_error(vm: &mut VM, e: &Error) -> Rc<Self>

Methods from Deref<Target = RModule>

pub fn getmcnst(&self, name: &str) -> Option<Rc<RObject>>

pub fn get_const_by_name(&self, name: &str) -> Option<Rc<RObject>>

pub fn find_method(&self, name: &str) -> Option<RProc>

pub fn full_name(self: &Rc<Self>) -> String